from orkestra.interfaces import Nextable


def coerce(obj: Nextable) -> Nextable:
    """
    Overload the `__rshift__` operator of obj to call its .next() method and do the same for the object it's called on.

    Args:
        obj: an object with a `.next(self, other)` method

    Returns: obj

    """

    def rshift(self, right):
        result = self.next(right)
        coerce(right)
        coerce(result)
        return result

    obj.__class__.__rshift__ = rshift
    return obj


def _cdk_patch(kwargs: dict):
    """
    Replace interface elements in kwargs with their cdk counterpart.
    """

    for key, value in kwargs.items():

        if hasattr(value, "cdk_construct"):

            kwargs[key] = value.cdk_construct

    return kwargs



from dataclasses import dataclass

import pytest

from examples.hello_orkestra import Item


@pytest.fixture(autouse=True)
def disable_powertools(monkeypatch):
    monkeypatch.setenv("POWERTOOLS_TRACE_DISABLED", "1")
    monkeypatch.setenv("POWERTOOLS_LOG_DEDUPLICATION_DISABLED", "1")


@pytest.fixture(scope="session")
def generic_context():
    @dataclass
    class LambdaContext:
        function_name: str = "test"
        memory_limit_in_mb: int = 128
        invoked_function_arn: str = (
            "arn:aws:lambda:eu-west-1:809313241:function:test"
        )
        aws_request_id: str = "52fdfc07-2182-154f-163f-5f0f9a621d72"

    return LambdaContext()


@pytest.fixture
def generic_event():
    return Item.random().dict()
